; NAME: 
;      ADD_AIR
; 
; PURPOSE: 
;      Adds airmass to CCD_FLUX output (for Apogee).
; 
; CALLING SEQUENCE: 
;      add_air, infile, airmass, path, [help=help]
; 
; INPUTS: 
;      infile - Filename of CCD_FLUX output
;      airmass - Airmass of infile
;      path - Path to infile
; 
; OPTIONAL KEYWORD INPUTS: 
;      help - Set to nonzero scalar to print syntax
; 
; OUTPUT: 
;      Airmass-added file overwrites infile
; 
; EXTERNAL CALLS: 
;      FILEX, NUMLINES
; 
; COMMON BLOCKS: 
;      NONE
; 
; MODIFICATION HISTORY: 
;      - Written by Eric Volquardsen, NASA IRTF, October 2003
; 
; =======================================================================
PRO add_air, infile, airmass, path, help=help

; CHECK INPUTS
     IF n_elements(help) EQ 1 THEN BEGIN
          IF help NE 0 THEN help = 1 
     ENDIF ELSE help = 0 
     IF n_elements(infile) NE 1 THEN help = 1 
     IF n_elements(airmass) NE 1 THEN help = 1 
     IF n_elements(path) NE 1 THEN help = 1 
     IF help EQ 1 THEN BEGIN
          print, '*********************************************'
          print, '***              ADD_AIR SYNTAX           ***'  
          print, '*** IDL> add_air, infile, airmass, path   ***' 
          print, '***                                       ***'
          print, '***  infile - Filename of CCD_FLUX output ***' 
          print, '***  airmass - Airmass of infile          ***' 
          print, '***  path - Path to infile                ***' 
          print, '*********************************************'   
          RETURN
     ENDIF

; LOAD INFILE
     ck = FILEX(infile, path)
     IF ck EQ 0 THEN BEGIN
          lines: 
          print, infile, ' DOES NOT EXIST'
          RETURN
     ENDIF
     cd, path, current=nowp
     nl = NUMLINES(infile)
     IF nl LT 21 THEN GOTO, lines 
     tabl1 = strarr(nl)
     openr, logun, infile, /get_lun
     readf, logun, tabl1
     free_lun, logun
     tabl1[8] = 'AIRMASS:                  ' + strtrim(string(airmass), 2)
     openu, logun, infile, /get_lun
     FOR j = 0, nl-1 DO printf, logun, tabl1[j]
     free_lun, logun
     cd, nowp
END
