; NAME: 
;      ERNOTE
; 
; VERSION: 1
; 
; PURPOSE: 
;      Provides a pop-up widget with designated error message.
; 
; CALLING SEQUENCE:
;      ernote, msg, topid, [ner=ner, help=help]
; 
; INPUTS:
;      msg- Error message to be displayed (< 40 characters)
;      topid- Top level base ID of caller used to make ERNOTE a 
;             floating, modal widget.
; 
; OPTIONAL KEYWORD INPUTS: 
;      ner- Set to non-zero scalar to send non error message (one beep)
;      help- Set to non-zero scalar to have ERNOTE print syntax
; 
; OUTPUT: 
;      Message is displayed and 3 beeps sound.
; 
; EXTERNAL CALLS: 
;      NONE
; 
; COMMON BLOCKS:
;      NONE
; 
; MODIFICATION HISTORY: 
;      -Written by Eric Volquardsen, NASA IRTF, March 2003
; 
; ====================================================================
;                     EVENT HANDLER MODULE
;                    ----------------------
PRO ernote_event, event 

   widget_control, event.top, /destroy

END

; =====================================================================
;                    WIDGET DEFINITION MODULE
;                   --------------------------
PRO ernote, msg, topid, ner=ner, help=help

; CHECK INPUTS: 
     IF n_elements(help) EQ 1 THEN BEGIN
          IF help NE 0 THEN help = 1 
     ENDIF ELSE help = 0 
     IF n_params() NE 2 THEN help = 1 
     IF help EQ 1 THEN BEGIN 
          print, '******************************************'
          print, '***           ERNOTE SYNTAX            ***'
          print, '*** > ernote, msg, topid, ner=ner      ***'
          print, '***                                    ***' 
          print, '*** msg- Error message to display      ***'
          print, '***      (< 40 characters)             ***' 
          print, '*** topid- Top level base ID of caller ***'
          print, '*** ner- Set to send non-error message ***'
          print, '***      (single beep)                 ***' 
          print, '******************************************'
          RETURN
     ENDIF 
     IF n_elements(ner) EQ 1 THEN BEGIN
          IF ner NE 0 THEN ner = 1 
     ENDIF ELSE ner = 0 

; MESSAGE/ERROR BEEPS
     ttl = '  MESSAGE  '
     print, string(7b), format='(a,$)'
     IF ner EQ 0 THEN BEGIN 
          wait, 0.25   
          print, string(7b), format='(a,$)'   
          wait, 0.25
          print, string(7b), format='(a,$)' 
          ttl = '  ERROR  '
     ENDIF   

; BASE WIDGET
     erbase = widget_base(title=ttl, group_leader=topid, /modal, $ 
          /floating, /frame, /column)

; TEXT WIDGET TO DISPLAY ERROR
     ertext = widget_text(erbase, value=msg, xsize=40)

; OK BUTTON WIDGET 
     okbutn = widget_button(erbase, value=' OK ')

; REALIZE AND REGISTER WITH XMANAGER
     widget_control, erbase, /realize
     xmanager, 'ernote', erbase, group_leader = topid


END
