; NAME:
;      FILEX
; 
; VERSION: 1
; 
; PURPOSE:
;      Checks for file in specified directory
; 
; CALLING SEQEUNCE:
;      check = filex(file, [dir, help=help])
; 
; INPUTS:
;      file- name of file to check
; 
; OPTIONAL INPUTS: 
;      dir- directory where file should be located (current is default)
; 
; OPTIONAL KEYWORD INPUTS:
;      help- set to nonzero integer to have FILEX print syntax
; 
; OUTPUT:
;      check- Set to zero if file does not exist or one if it does
; 
; EXTERNAL CALLS: 
;      NONE 
; 
; COMMON BLOCKS: 
;      NONE 
; 
; MODIFICATION HISTORY:
;      -Written by Eric Volquardsen, NASA IRTF, March 2003
;   
; =======================================================================
FUNCTION filex, file, dir, check, help=help

; CHECK INPUTS
     IF n_elements(file) NE 1 THEN help = 1 
     v = !version.os_family
     CASE v OF
          'vms' : BEGIN 
               root = '[]'  
               delim = ']'
          END
          'windows' : BEGIN 
               root = 'c:\' 
               delim = '\'
          END
          ELSE : BEGIN 
          root = '/'  
          delim = '/'
          END
     ENDCASE
     IF n_elements(dir) NE 1 THEN BEGIN
          cd, root, current=dir
          cd, dir
          dir = dir + delim
     ENDIF 
     ss1 = strpos(dir, delim, /reverse_search)
     ss2 = strlen(dir)-1
     IF ss1 NE ss2 THEN dir = dir + delim
     IF n_elements(help) EQ 1 THEN BEGIN
          IF help NE 0 THEN BEGIN
               print, '*******************************************'
               print, '***            FILEX SYNTAX             ***'
               print, '*** > check = filex(file, dir)          ***'
               print, '***                                     ***'
               print, '*** file- name of file to check         ***'
               print, '*** dir- directory where file should be ***'
               print, '***      located (default is current)   ***'
               print, '*******************************************'
               RETURN, 0
          ENDIF
     ENDIF

; CHECK FOR FILE
     fn = dir + file
     junk = findfile(fn, count=check)
     IF check NE 0 THEN check = 1 
     RETURN, check

END
