; NAME: 
;      LINEID
; 
; VERSION: 1
; 
; PURPOSE: 
;      User locates calibration lines.
; 
; CALLING SEQUENCE: 
;      lineid
; 
; INPUTS: 
;      User will enter 1) Full input filename
;                      2) Full output filename
;                      3) Identified line estimate 
;                      4) Wavelength
; 
; OUTPUT: 
;      Fit parameters saved in ascii file
; 
; EXTERNAL CALLS: 
;      BREAK_FILE, COYOTE_FIELD, ERNOTE, FILEX, REMOVE, SPEC_PLOT
; 
; COMMON BLOCKS: 
;      NONE 
; 
; MODIFICATION HISTORY: 
;      - Written by Eric Volquardsen, NASA IRTF, April 2003
; 
; ============================================================================
;                           EVENT HANDLER MODULE
;                          ----------------------
PRO lineid_event, event

; SEPARATE EVENTS
     widget_control, event.id, get_uvalue=v
     widget_control, event.top, get_uvalue=dst
     CASE v OF

; ----- LOAD BUTTON -----

          'load' : BEGIN

; Get needed structure info
               fnames = dst.fnames
               inp = fnames[0]
               dta = *dst.dta
               widget_control, dst.specds, get_value=wid
               wset, wid
               break_file, inp, junk, inpath, fn, ex
               infile = fn + ex

; Reset values
               *dst.setl = [-1.0d]
               *dst.setw = [0.0d]
               dst.co = fltarr(6)
               dst.cer = fltarr(6)
               *dst.yf = fltarr(6)
               widget_control, long(dst.fldl), set_value=0.0d
               widget_control, long(dst.fldw), set_value=0.0d

; Check for file
               ck = filex(infile, inpath)
               IF ck EQ 0 THEN BEGIN
                    msg = 'CANT LOAD FILE' 
                    ernote, msg, event.top 
                    widget_control, event.top, set_uvalue=dst, /no_copy
                    RETURN
               ENDIF

; Get and display data
               spec_plot, infile, path=inpath, datao=dta

; Return data structure
               *dst.dta = dta
               widget_control, event.top, set_uvalue=dst, /no_copy

          END   ; load button

; ----- SAVE BUTTON -----

          'savb' : BEGIN

; Get needed structure info
               fnames = dst.fnames
               co = dst.co
               cer = dst.cer
               yf = *dst.yf
               setl = *dst.setl
               setw = *dst.setw
               inp = fnames[0]
               break_file, inp, junk, pat, fn1, ex1
               file1 = fn1 + ex1
               otp = fnames[1]
               break_file, otp, junk, pa, fn, ex
               file = fn + ex

; Create output table
               s = size(yf, /dimensions)
               IF n_elements(s) NE 1 THEN s = s[1]
               tbl = fltarr(3, s)
               tbl[0, *] = setl
               tbl[1, *] = setw
               tbl[2, *] = yf

; Save results
               cd, pa, current=nowp
               ck = filex(file, pa)
               IF ck EQ 0 THEN openw, logun, file, /get_lun $ 
                    ELSE openw, logun, file, /get_lun, /append
               printf, logun, systime()
               printf, logun, 'Source File: ', file1
               printf, logun, '    Calibration Lines '
               printf, logun, '      line #     wavelength   fitted wl'
               printf, logun, tbl
               printf, logun, '    Coefficients for polynomial fit'
               printf, logun, transpose(co)
               printf, logun, '    Coefficient errors '
               printf, logun, transpose(cer)
               printf, logun, '                                '
               printf, logun, '                                '
               free_lun, logun
               cd, nowp

; Plot results
               plot, tbl[0,*], tbl[1,*], psym=1, title='Calibration Fit'
               oplot, tbl[0,*], tbl[2,*]

; Return structure
               widget_control, event.top, set_uvalue=dst, /no_copy

          END   ; save button

; ----- EXIT BUTTON -----

          'extb' : BEGIN

               widget_control, event.top, /destroy
               RETURN

          END   ; exit buttonevent

; ----- SET LINE BUTTON -----

          'setb' : BEGIN

; Get structure info
               lnf = dst.lnf
               wvf = dst.wvf
               setl = *dst.setl
               setw = *dst.setw
               pkf = dst.pkf
               dta = *dst.dta
               rad = dst.rad
               fldl = long(dst.fldl)
               IF lnf LT 1 THEN lnf = 1 
               IF wvf LE 0 THEN BEGIN
                    msg = 'NEED WAVELENGTH VALUE' 
                    ernote, msg, event.top 
                    widget_control, event.top, set_uvalue=dst, /no_copy
                    RETURN
               ENDIF

; Get peak region
               n = n_elements(dta)
               IF n LT 9 THEN BEGIN
                    msg = 'SPECTRUM NOT LOADED'
                    ernote, msg, event.top 
                    widget_control, event.top, set_uvalue=dst, /no_copy
                    RETURN
               ENDIF
               mx = max(dta[0, *])
               lrng = [(lnf-rad > 0), (lnf+rad < mx)]
               sz = lrng[1] - lrng[0] + 1 
               reg = intarr(sz)
               reg = transpose(dta[1, lrng[0]:lrng[1]])

; Calculate peak location
               IF pkf EQ 'cent' THEN BEGIN 
                    fwhm = fullwid_halfmax(reg, centroid=lin)
                    IF n_elements(lin) NE 1 THEN BEGIN
                         msg = 'UNABLE TO LOCATE PEAK'
                         ernote, msg, event.top 
                         widget_control, event.top, set_uvalue=dst, /no_copy
                         RETURN
                    ENDIF
               ENDIF ELSE maxx = max(reg, lin)
               lin = (lin + lrng[0])

; Set values
               widget_control, fldl, set_value=lin
               dst.lnf = lin
               setln = setl[0]
               IF setln EQ -1 THEN BEGIN
                    *dst.setl = [lin]
                    *dst.setw = [wvf]
               ENDIF ELSE BEGIN
                    *dst.setl = [setl, lin]
                    *dst.setw = [setw, wvf]
               ENDELSE

; Return structure
               widget_control, event.top, set_uvalue=dst, /no_copy

          END   ; set button

; ----- UNSET LINE BUTTON -----

          'uset' : BEGIN

; Get structure info
               lnf = dst.lnf
               setl = *dst.setl
               setw = *dst.setw

; Find entry to remove
               indx = where(setl EQ lnf)
               IF indx EQ -1 THEN BEGIN
                    msg = 'SELECTED LINE WAS NEVER SET'
                    ernote, msg, event.top  
                    widget_control, event.top, set_uvalue=dst, /no_copy
                    RETURN
               ENDIF
               n = n_elements(indx)

; Remove values
               IF n LT n_elements(setl) THEN BEGIN
                    remove, indx, setl, setw
               ENDIF ELSE BEGIN
                    setl = [-1]
                    setw = [0]
               ENDELSE

; Return structure
               *dst.setl = setl
               *dst.setw = setw
               widget_control, event.top, set_uvalue=dst, /no_copy

          END   ; unset button

; ----- CALCULATE BUTTON -----

          'calc' : BEGIN

; Get structure info
               setl = *dst.setl
               setw = *dst.setw
               ptused = n_elements(setl)
               IF ptused LT 2 THEN BEGIN
                    msg = 'NOT ENOUGH LINES SELECTED'
                    ernote, msg, event.top  
                    widget_control, event.top, set_uvalue=dst, /no_copy
                    RETURN
               ENDIF 

; Calculate line-wavelength relation
               ptused1 = ptused < 6
               co = poly_fit(setl, setw, (ptused1-1), sigma=cer, yfit=yf, $ 
                    /double)

; Report results
               msg = strtrim(string(ptused), 2) + ' lines w/coefficient sigma '+ $
                     strtrim(string(cer), 2)
               ernote, msg, event.top, ner=1

; Return structure
               dst.co = co
               dst.cer = cer
               *dst.yf = yf
               widget_control, event.top, set_uvalue=dst, /no_copy

          END   ; calculate button

; ----- ZOOM BUTTON -----

          'zmbt' : BEGIN

               dta = *dst.dta
               IF n_elements(dta) LT 2 THEN BEGIN
                    widget_control, event.top, set_uvalue=dst, /no_copy
                    RETURN
               ENDIF
               fnames = dst.fnames
               zoom = dst.zoom
               IF zoom EQ 0 THEN BEGIN
                    zoom = 1 
                    r1 = min(dta[1, *], max=r2)
                    r2 = r1 + (r2-r1)/10
                    plot, dta[0, *], dta[1, *], charsize=1.5, yrange = [r1, r2], $ 
                         title='Zoomed spectrum for '+fnames[0]
               ENDIF ELSE BEGIN
                    zoom = 0
                    plot, dta[0, *], dta[1, *], charsize=1.5, $ 
                         title='Spectrum for '+fnames[0]
               ENDELSE
               dst.zoom = zoom
               widget_control, event.top, set_uvalue=dst, /no_copy

          END   ; zoom button

; ----- INPUT FILE -----

          'infl' : BEGIN

               fnames = dst.fnames
               widget_control, event.id, get_value=pv
               fnames[0] = (*pv)
               dst.fnames = fnames
               widget_control, event.top, set_uvalue=dst, /no_copy

          END   ; input file field

; ----- OUTPUT FILE -----

          'otfl' : BEGIN

               fnames = dst.fnames
               widget_control, event.id, get_value=pv
               fnames[1] = (*pv)
               dst.fnames = fnames
               widget_control, event.top, set_uvalue=dst, /no_copy

          END   ; output file field

; ----- INPUT BROWSE BUTTON -----

          'brsi' : BEGIN

               br = dialog_pickfile(filter='*', /read)
               fnames = dst.fnames
               fnames[0] = br
               dst.fnames = fnames
               widget_control, event.handler, set_value=br
               widget_control, event.top, set_uvalue=dst, /no_copy

          END   ; input browse button

; ----- OUTPUT BROWSE BUTTON -----

          'brso' : BEGIN

               br = dialog_pickfile(filter='*', /read)
               fnames = dst.fnames
               fnames[1] = br
               dst.fnames = fnames
               widget_control, event.handler, set_value=br
               widget_control, event.top, set_uvalue=dst, /no_copy

          END   ; output browse button

; ----- LINE NUMBER FIELD -----

          'fldl' : BEGIN

               lnf = dst.lnf
               widget_control, event.id, get_value = pv
               lnf = (*pv)
               IF lnf LT 0 THEN lnf = abs(lnf)
               dst.lnf = lnf 
               widget_control, event.top, set_uvalue=dst, /no_copy

          END   ; line number field

; ----- WAVELENGTH FIELD -----

          'fldw' : BEGIN

               wvf = dst.wvf
               widget_control, event.id, get_value = pv
               wvf = (*pv)
               IF wvf LT 0 THEN wvf = abs(wvf)
               dst.wvf = wvf 
               widget_control, event.top, set_uvalue=dst, /no_copy

          END   ; wavelength field

; ----- PEAK LOCATION FIELD -----

          'fldp' : BEGIN

               pkf = dst.pkf
               widget_control, event.id, get_value = pv
               pkf = (*pv)
               IF pkf NE 'cent' THEN BEGIN
                    IF pkf NE 'max' THEN BEGIN
                         msg = 'ALLOWED VALUES ARE CENT or MAX'
                         ernote, msg, event.top 
                         widget_control, event.top, set_uvalue=dst, /no_copy
                         RETURN
                    ENDIF
               ENDIF
               dst.pkf = pkf 
               widget_control, event.top, set_uvalue=dst, /no_copy

          END   ; peak location field

; ----- SEARCH RADIUS FIELD -----

          'fldr' : BEGIN

               rad = dst.rad
               widget_control, event.id, get_value = pv
               rad = (*pv)
               IF rad LT 2 THEN BEGIN 
                    rad = 2.0 
                    widget_control, event.id, set_value=rad
               ENDIF
               dst.rad = rad
               widget_control, event.top, set_uvalue=dst, /no_copy

          END   ; search radius field

; ----- SPECTRA DISPLAY -----

          'spcd' : BEGIN

               IF event.press EQ 1 THEN BEGIN
                    x = event.x
                    y = event.y
                    coord = convert_coord(x, y, /device, /to_data)
                    widget_control, long(dst.fldl), set_value=coord[0]
                    dst.lnf = coord[0]
               ENDIF
               widget_control, event.top, set_uvalue=dst, /no_copy

          END   ; spectra display event

     ENDCASE   ; filename field event separation

END   ; main event handler

; ===========================================================================

; POINTER CLEANUP
PRO lineid_clean, linetb

     widget_control, linetb, get_uvalue=dst, /no_copy
     IF n_elements(dst) EQ 0 THEN heap_gc ELSE BEGIN
          ptr_free, dta
          ptr_free, setl
          ptr_free, setw
          ptr_free, yf
     ENDELSE

END   ; cleanup routine

; ============================================================================
;                         WIDGET DEFINITION MODULE
;                        --------------------------
PRO lineid

; INITIALIZE DATA STRUCTURE
     fnames = strarr(2)       ; full file names
     lnf = 0.0d               ; line field
     wvf = 0.0d               ; wavelength field 
     fldl = 0                 ; line field ID
     fldw = 0                 ; wavelength field ID
     specds = 0               ; spectra display ID
     rad = 5.0                ; peak finder search radius
     dta = 0.0                ; data table pointer
     pkf = 'cent'             ; Method of peak location field
     co = fltarr(6)           ; fit coefficient
     setl = [-1.0d]           ; vector of set lines
     setw = [0.0d]            ; vector of set wavelengths
     cer = fltarr(6)          ; standard dev. of coefficients
     yf = fltarr(6)           ; fitted wavelength values pointer 
     zoom = 0                 ; tracks setting of y-axis zoom
     dst = { fnames:fnames, lnf:lnf, wvf:wvf, fldl:fldl, fldw:fldw, zoom:zoom, $ 
             specds:specds, rad:rad, cer:cer, dta:ptr_new(dta), pkf:pkf, $ 
             co:co, setl:ptr_new(setl), yf:ptr_new(yf), setw:ptr_new(setw) }

; BASE WIDGETS
     linetb = widget_base(title='LINE IDENTIFICATION     ', $ 
              /column, mbar=menub)
     pathbs = widget_base(linetb, /column, frame=8)
     fldbas = widget_base(linetb, /row, frame=8)
     displb = widget_base(linetb, frame=8)

; BUTTON WIDGETS
     filebt = widget_button(menub, value=' FILE ')
     loadbt = widget_button(filebt, value='Load', uvalue='load')
     savebt = widget_button(filebt, value='Save', uvalue='savb')
     exitbt = widget_button(filebt, value='Exit', uvalue='extb')
     locbut = widget_button(menub, value=' LOCATE ')
     setbut = widget_button(locbut, value='Set Line', uvalue='setb')
     usetbt = widget_button(locbut, value='Unset Line', uvalue='uset')
     calcbt = widget_button(locbut, value='Calculate', uvalue='calc')
     zoombt = widget_button(locbut, value='Zoom', uvalue='zmbt')

; PATH WIDGETS
     infl = coyote_field(pathbs, uvalue='infl', /cr_only, $ 
            value=dst.fnames[0], title='                     INPUT FILE ', $ 
            xsize=60, event_pro='lineid_event')
     brsi = widget_button(infl, value='BROWSE', uvalue='brsi')
     otfl = coyote_field(pathbs, uvalue='otfl', /cr_only, $ 
            value=dst.fnames[1], title='                    OUTPUT FILE ', $ 
            xsize=60, event_pro='lineid_event')
     brso = widget_button(otfl, value='BROWSE', uvalue='brso')

; FIELD WIDGETS
     fldl = coyote_field(fldbas, uvalue='fldl', /cr_only, $ 
            value=dst.lnf, title='Line Number', $ 
            event_pro='lineid_event', scr_xsize=76)
     fldw = coyote_field(fldbas, uvalue='fldw', /cr_only, $ 
            value=dst.wvf, title='   Wavelength', $ 
            event_pro='lineid_event', scr_xsize=77)
     fldp = coyote_field(fldbas, uvalue='fldp', /cr_only, $ 
            value=dst.pkf, title='   Peak Locator (cent/max)', $ 
            event_pro='lineid_event', scr_xsize=75)
     fldr = coyote_field(fldbas, uvalue='fldr', /cr_only, $ 
            value=dst.rad, title='   Search radius', $ 
            event_pro='lineid_event', scr_xsize=75)

; DISPLAY WIDGETS
     specds = widget_draw(displb, /button_events, uvalue='spcd', $ 
              xsize=800, ysize=600)

; WIDGET ACTIVATION
     dst.fldl = fldl 
     dst.fldw = fldw
     dst.specds = specds
     widget_control, linetb, set_uvalue = dst, /no_copy
     widget_control, linetb, /realize
     xmanager, 'lineid', linetb, cleanup=lineid_clean

END   ; event handler
