; NAME: 
;      MAKE_DARK
; 
; VERSION: 1
; 
; PURPOSE: 
;      Creates average dark from several dark files by finding 
;      median value at each pixel.
; 
; CALLING SEQUENCE: 
;      make_dark, darks, outfn, [path=path, help=help])
; 
; INPUTS: 
;      darks - String vector of dark filenames
;      outfn - Filename for average dark
; 
; OPTIONAL KEYWORD INPUTS: 
;      path - String vector of the paths for input and output files
;      help - Set to nonzero scalar to print syntax
; 
; OUTPUT: 
;      Results are saved to outfn 
; 
; EXTERNAL CALLS: 
;      FXADDPAR, FXWRITE, GETIM, MEDARR
; 
; COMMON BLOCKS: 
;      NONE
; 
; MODIFICATION HISTORY: 
;      - Written by Eric Volquardsen, NASA IRTF, February 2004
; 
; =======================================================================
PRO make_dark, darks, outfn, path=path, help=help

; CHECK INPUTS
     IF n_elements(help) EQ 1 THEN BEGIN
          IF help NE 0 THEN help = 1 
     ENDIF ELSE help = 0 
     nd = n_elements(darks)
     IF nd LT 2 THEN help = 1 
     IF n_elements(outfn) EQ 0 THEN help = 1
     IF help EQ 1 THEN BEGIN
          print, '**************************************************'
          print, '***             MAKE_DARK SYNTAX               ***'  
          print, '*** IDL> make_dark, darks, outfn, path=path    ***' 
          print, '***                                            ***' 
          print, '*** darks - String vector of dark filenames    ***' 
          print, '*** outfn - Output filename                    ***' 
          print, '*** path - String vector of the paths          ***' 
          print, '**************************************************'   
          RETURN
     ENDIF
     np = n_elements(path)
     CASE np OF 
          0 : BEGIN
               v = !version.os_family
               CASE v OF
                    'vms' : root = '[]'
                    'windows' : root = 'c:\'
                    ELSE : root = '/'
                ENDCASE
                cd, root, current=pat
                cd, pat
                path = [pat, pat]
          END
          1 : path = [path, path]
          ELSE : path = path[0:1]
     ENDCASE
     outfn = outfn[0]

; READ DARKS 
     dl = ''
     FOR i = 0, (nd-1) DO BEGIN
          dl = dl + darks[i] + '/'
          GETIM, darks[i], im, path[0], hdr=h 
          IF n_elements(im) LT 10 THEN RETURN
          IF i EQ 0 THEN BEGIN 
               sz = size(im,  /dimension)
               ar = fltarr(sz[0], sz[1], nd)
          ENDIF 
          ar[*, *, i] = im
     ENDFOR

; CREATE AVERAGE DARK
     MEDARR, ar, sub

; CREATE HEADER
     FXADDPAR, h, 'COMMENT', '= Median of original darks'
     FXADDPAR, h, 'ORIGINAL', dl
     FXADDPAR, h, 'BITPIX', -32

; SAVE RESULTS
     cd, path[1], current=nowp
     FXWRITE, outfn, h, sub
     cd, nowp

END
