; NAME: 
;      MEAN_TM
; 
; PURPOSE: 
;      To return a 24 hr clock time string that is the mean
;      of several time strings.  Format for time string is 
;      'HH:MM:SS.SS' for input and 'HH:MM:SS' for output.
; 
; CALLING SEQUENCE: 
;      mean_tm, headers, tm_keyword, meant, [help=help]
; 
; INPUTS: 
;      headers- string vector of header names
;      tm_keyword- FITS keyword where time is located
; 
; OPTIONAL KEYWORD INPUTS: 
;      help- set to nonzero scalar to have MEAN_TM print syntax
; 
; OUTPUT: 
;      meant- new time string
; 
; EXTERNAL CALLS: 
;      FXPAR, GETWRD, ROUND_OFF
; 
; COMMON BLOCKS: 
;      NONE 
; 
; MODIFICATION HISTORY: 
;      - Written by Eric Volquardsen, NASA IRTF, Jan. 2003
; 
; =========================================================================
PRO mean_tm, headers, tm_keyword, meant, help=help

; CHECK INPUTS
     IF n_elements(help) EQ 1 THEN BEGIN
          IF help NE 0 THEN help = 1 
     ENDIF ELSE help = 0 
     szh = n_elements(headers)
     IF szh LT 1 THEN help = 1 
     IF n_elements(tm_keyword) NE 1 THEN help = 1 
     IF help EQ 1 THEN BEGIN
          print, '*************************************************'
          print, '***               MEAN_TM SYNTAX              ***'
          print, '*** > mean_tm, headers, tm_keyword, meant     ***'
          print, '***                                           ***'
          print, '*** headers- string vector of header names    ***'
          print, '*** tm_keyword- FITS observation time keyword ***'
          print, '*** meant- new time string of mean times      ***'
          print, '*************************************************'
          RETURN
     ENDIF

; INITIALIZE VALUES 
     tttt = fltarr(szh)
     meant = ''

; LOOP THROUGH HEADERS 
     FOR i = 0, (szh-1) DO BEGIN

; Get time string
          thist = strtrim(fxpar(headers[i], tm_keyword), 2)

; Separate hrs, mins, secs
          hr = fix(getwrd(thist, 0, delimiter=':'))
          minit = fix(getwrd(thist, 1, delimiter=':'))
          secnd = float(getwrd(thist, 2, delimiter=':'))

; Put as floating point number of seconds
          tttt[k] = 3600*hr+60*minit+secnd

     ENDFOR   ; header loop

; FIND MEAN OF STRING TIMES
     mntime = total(tttt)/float(szh)
     mhr = strtrim(fix(mntime/3600), 2)
     mminit = strtrim(fix((mntime-3600*mhr)/60), 2) 
     msecnd = strtrim(round(mntime-3600*mhr-60*mminit), 2)
     IF strlen(mhr) EQ 1 THEN mhr = '0'+mhr
     IF strlen(mminit) EQ 1 THEN mminit = '0'+mminit
     IF strlen(msecnd) EQ 1 THEN msecnd = '0'+msecnd
     meant = string(mhr)+':'+string(mminit)+':'+string(msecnd)

END   