; NAME: 
;      MFIND
; 
; PURPOSE: 
;      To find mirsi positive image elements
; 
; CALLING SEQUENCE: 
;      mfind, infiles, path
; 
; INPUTS: 
;      infiles - Filenames of images with stars to find
; 
; 
; OUTPUT:
;      Star coordinates are printed to screen
; 
; EXTERNAL CALLS: 
;      FILEX, FIND, GETIM, IM_STATS
; 
; COMMON BLOCK: 
;      NONE 
; 
; MODIFICATION HISTORY: 
;      - Written by Eric Volquardsen, NASA IRTF, November 2003
; 
; =========================================================================
PRO mfind, infile, path

; LOAD IMAGE
     infile = infile[0]
     chk = FILEX(infile, path)
     IF chk EQ 0 THEN BEGIN 
          print, infile, ' DOES NOT EXIST'
          RETURN
     ENDIF 
     GETIM, infile, img, path, hdr=hdr
     sz = size(img)
     IF sz[0] EQ 3 THEN img = img[*,*,0]

r = filter_image(img, smooth=30)
img = img - r 


; FIND STARS
     delta = [70, 73]
     stat = IM_STATS(img)
     sky = (stat.sky_Level) > stat.average
     sky = sky > 1.0
     m = 0.9*(stat.max/stat.sigma_noise)
     hmin = m * sky
     fwhm = 4.0 
     roundlim = [-1.0, 1.0]
     sharplim = [0.2, 1.0]
     FIND, img, x, y, flux, sharp, round, hmin, fwhm, roundlim, $ 
           sharplim, /SILENT 
     xy = CN_COMP(delta, x, y)     
     x = xy[0:1,0]
     y = xy[0:1,1]
     print, 'x: ', x
     print, 'y: ', y

END 







