; NAME: 
;      READ_ATRN
; 
; PURPOSE: 
;      Reads ATRAN model files generated by Eric Volquardsen
; 
; CALLING SEQUENCE: 
;      table = read_atrn(file, path, [help=help])
; 
; INPUTS: 
;      FILE - ATRAN model filename
;      PATH - Directory where FILE is located
; 
; OPTIONAL KEYWORD INPUTS: 
;      HELP - Set to nonzero scalar to print syntax
; 
; OUTPUT: 
;      TABLE - 61 column by 9000 row array with each column containing 
;              the transmission coefficients for a particular atmospheric
;              water quantity.  The wavelengths go from 2.00 microns to 
;              4.25 microns in increments 0f 0.00025 microns.  Water 
;              amounts go from 0 mm to 5.9 mm in 0.1 mm increments.
;              The first column is wavelength.
; 
; EXTERNAL CALLS: 
;      FILEX
; 
; COMMON BLOCKS: 
;      NONE 
; 
; MODIFICATION HISTORY: 
;      - Written by Eric Volquardsen, NASA IRTF, July 2003
; 
; =======================================================================
FUNCTION read_atrn, file, path, help=help

; CHECK INPUTS
     IF n_elements(help) EQ 1 THEN BEGIN 
          IF help NE 0 THEN help = 1
     ENDIF ELSE help = 0 
     IF n_elements(file) NE 1 THEN help = 1 
     IF n_elements(path) NE 1 THEN help = 1 
     IF help EQ 1 THEN BEGIN
          print, '**********************************************'
          print, '***             READ_ATRN SYNTAX           ***' 
          print, '*** > table = read_atrn(file, path)        ***' 
          print, '***                                        ***'
          print, '*** FILE - Input filename                  ***' 
          print, '*** PATH - Directory where FILE is located ***' 
          print, '*** TABLE - Array located in FILE          ***'  
          print, '**********************************************' 
          RETURN, 0 
     ENDIF 
     chk = FILEX(file, path)
     IF chk EQ 0 THEN BEGIN
          msg = file + ' DOES NOT EXIST'
          print, msg
          RETURN, 0
     ENDIF 

; READ FILE
     data = fltarr(61)
     table = fltarr(61, 9000)
     cd, path, current=nowp
     openr, logun, file, /get_lun
     FOR i=0, 8999 DO BEGIN
          readf, logun, data
          table[*, i] = data
     ENDFOR
     free_lun, logun
     cd, nowp

; RETURN TABLE
     RETURN, table

END 
