; NAME: 
;      READ_SPEC
; 
; VERSION: 1
; 
; PURPOSE: 
;      Reads three or four column spectrum table in ascii format
; 
; CALLING SEQUENCE: 
;      table = read_spec(file, path, [flag=flag, help=help])
; 
; INPUTS: 
;      FILE - filename of spectra
;      PATH - directory where FILE is located
; 
; OPTIONAL KEYWORD INPUTS: 
;      FLAG - Set if spectrum has a fourth column
;      HELP - Set to nonzero scalar to have READ_SPECTRA print syntax
; 
; OUTPUT: 
;      TABLE - three column spectrum table 
; 
; EXTERNAL CALLS: 
;      FILEX, READCOL
; 
; COMMON BLOCKS: 
;      NONE 
; 
; MODIFICATION HISTORY: 
;      - Written by Eric Volquardsen, NASA IRTF, May 2003
; 
; =======================================================================
FUNCTION read_spec, file, path, flag = flag, help=help

; CHECK INPUTS
     IF n_elements(help) EQ 1 THEN BEGIN 
          IF help NE 0 THEN help = 1
     ENDIF ELSE help = 0 
     IF n_elements(file) NE 1 THEN help = 1 
     IF n_elements(path) NE 1 THEN help = 1 
     IF help EQ 1 THEN BEGIN
          print, '**************************************************'
          print, '***               READ_SPEC SYNTAX             ***' 
          print, '*** > table = read_spec(file, path, flag=flag) ***' 
          print, '***                                            ***'
          print, '*** FILE - Input filename                      ***' 
          print, '*** PATH - Directory where FILE is located     ***' 
          print, '*** FLAG - Set if spectrum has a fourth col.   ***'
          print, '*** TABLE - Spectrum located in FILE           ***'  
          print, '**************************************************' 
          RETURN, 0 
     ENDIF 
     chk = FILEX(file, path)
     IF chk EQ 0 THEN BEGIN
          msg = file + ' DOES NOT EXIST'
          print, msg
          RETURN, 0
     ENDIF 
     IF n_elements(flag) NE 1 THEN flag = 0

; READ FILE
     cd, path, current=nowp
     IF flag EQ 0 THEN $ 
          READCOL, file, line, cts, er, format='f, f, f', /silent $ 
     ELSE READCOL, file, line, cts, er, f, format='f, f, f, f', /silent 
     cd, nowp

; RETURN TABLE
     IF flag EQ 0 THEN n = 3 ELSE n = 4
     s = max(size(line, /dimensions))
     table = fltarr(n, s)
     table[0, *] = line
     table[1, *] = cts
     table[2, *] = er 
     IF n EQ 4 THEN table[3, *] = f
     RETURN, table

END 
